@@ -258,19 +258,30 @@ def postprocess(chroms):
 		for i in range(init,len(chroms),3):
 			
 			n_chrom = int(i/3)+1
-			
+
 			if len(chroms[i][0][0]) > 0 and len(chroms[i][1][0]) > 0:
 				sum_p_c = np.concatenate((sum_p_c, np.array([str(n_chrom)])))
 				sum_n_c = np.concatenate((sum_n_c, np.array([str(n_chrom)])))
 			elif len(chroms[i][0][0]) != len(chroms[i][1][0]):
 				sum_p_c = np.concatenate((sum_p_c, np.array([str(n_chrom)])))
 				sum_n_c = np.concatenate((sum_n_c, np.array([str(n_chrom)])))
-			else:	
-				sum_p_c = np.concatenate((sum_p_c, chroms[i][0][0]))
-				sum_n_c = np.concatenate((sum_n_c, chroms[i][1][0]))
-				
-			sum_p_n = np.array(np.concatenate((sum_p_n, chroms[i][0][1])))
-			sum_n_n = np.array(np.concatenate((sum_n_n, chroms[i][1][1])))
+			else:
+				if len(chroms[i][0][0]) == 0:
+					sum_p_c = np.concatenate((sum_p_c, np.array(["1"], dtype='<U32')))
+				else:
+					sum_p_c = np.concatenate((sum_p_c, chroms[i][0][0]))
+				if len(chroms[i][1][0]) == 0:
+					sum_n_c = np.concatenate((sum_n_c, np.array(["1"], dtype='<U32')))
+				else:
+					sum_n_c = np.concatenate((sum_n_c, chroms[i][1][0]))
+			if len(chroms[i][0][1]) == 0:
+				sum_p_n = np.array(np.concatenate((sum_p_n, np.array([0], dtype=np.float64))))
+			else:
+				sum_p_n = np.array(np.concatenate((sum_p_n, chroms[i][0][1])))
+			if len(chroms[i][1][1]) == 0:
+				sum_n_n = np.array(np.concatenate((sum_n_n, np.array([0], dtype=np.float64))))
+			else:
+				sum_n_n = np.array(np.concatenate((sum_n_n, chroms[i][1][1])))
 		
 		return [(np.array(sum_p_c),np.array(sum_p_n)),(np.array(sum_n_c),np.array(sum_n_n))]
 	
@@ -367,7 +378,9 @@ def create_feature(gbk_filename, tmp, output, sizes, feat, cogs_dict=None, divid
 	
 	if hist1 is not None and hist2 is not None:
 		hist1 = hist1.set_index("cat").add(hist2.set_index("cat"), fill_value=0).reset_index().replace("None", "Unclassified")
-		hist1.columns = ["COG Category", "Frequency"] + ["chr"+str(x) for x in sorted(list(set(chrms_p+chrms_n)))]
+		hist1 = hist1.rename(columns={'freq': 'Frequency', 'cat': 'COG Category'})
+		hist1 = hist1[["COG Category", "Frequency"] + ["chr"+str(x) for x in sorted(list(set(chrms_p+chrms_n)))]] # Reordering columns
+		#hist1.columns = ["COG Category", "Frequency"] + ["chr"+str(x) for x in sorted(list(set(chrms_p+chrms_n)))]
 	
 		#if hist1 is not None and hist2 is not None:
 		#	hist1 = hist1.set_index("cat").add(hist2.set_index("cat"), fill_value=0).reset_index().replace("None", "Unclassified")
